=======
History
=======

0.4.0 (2024-12-19)
------------------

* Updated Python version requirement to >=3.9 (breaking change)
* Updated development dependencies to latest versions
* Updated CI/CD configuration for Python 3.9+

0.1.0 (2022-03-27)
------------------

* First release on PyPI.
